var md5 = require('md5');
var fse = require('fs-extra');
var path = require('path');

function PHPAssetVerPlugin(configFile, options) {
  this.configFile = configFile;
  this.options = options || {};
}

PHPAssetVerPlugin.prototype.apply = function(compiler) {
  compiler.plugin(
    'emit',
    function(compilation, callback) {
      var outputPath = compiler.outputPath;
      var phpconfig = ['<?php\n', 'return ['];
      var jsonconfig = ['{'];

      compilation.chunks.forEach(function(chunk) {
        chunk.files.forEach(function(filename) {
          var source = compilation.assets[filename].source();
          var hash = md5(source).substr(0, 10);
          phpconfig.push(`    '${filename}' => '${hash}',`);
          jsonconfig.push(`    "${filename}": "${hash}",`);
        });
      });
      phpconfig.push('];');
      jsonconfig.push('}');
      fse.outputFileSync(this.configFile, phpconfig.join('\n'));
      fse.outputFileSync(this.options.json, jsonconfig.join('\n'));

      callback();
    }.bind(this)
  );
};

module.exports = PHPAssetVerPlugin;
